@@ -20,7 +20,7 @@ import json
 import getpass
 from bs4 import BeautifulSoup as bs
 from datetime import datetime as dt
-v='2.5.97'
+v='2.6.97'
 n='civilianM'
 a='AC97'
 m='AC96'
@@ -29,19 +29,9 @@ __all__ = ('upgrade','checkClass','wait','randint','decimal','garbledCode','paus
     'LibraryError','ConscienceError','ArgeementWarning','openWeb','UnknownError','whatNews')
 #print("欢迎使用civilianM，当前版本："+v)
 def whatNews():
-    whatNew = ['2021-10-16 civilianM-2.5.97 更新日志',
-        '1.cMES(civilianM Encry Standard |civilianM加密标准)更新至1.0代',
-        '2.openFolder()参数 fn可以忽略',
-        '3:增加openWeb()功能',
-        '4. find()使用search()以后需要find().show获取结果',
-        '5.error()类新增加5种错误，并且忽略cont参数时，只会返回 " "',
-        '6. cert.py/do()全部改中文',
-        '7.civilianM增加一位维护员：AC96',
-        '8. login.py缓存文件future.whl更名dontlook.fkyu',
-        '9.删除了PyOpenSSL依赖库',
-        '10.author()增加新函数：manage()',
-        '11.访问author()的函数时无需加括号。（a=author;a.manage）',
-        '12.author() old()不返回LibraryError']
+    whatNew = ['2021-10-16 civilianM-2.6.97 更新日志',
+        '1.readme.md有更改',
+        '2:decimal函数有改动']
     for n in whatNew:
         if n == whatNew[0]:
             print(n)
@@ -126,10 +116,13 @@ def decimal(mins,maxs,save=None):
             rm
             .uniform(mins,maxs))
     elif save != None:
+        reutrn = (
+            rm
+            .uniform(mins,maxs))
         return (
             round(
-            rm
-            .uniform(mins,maxs)),save)
+                reutrn,save)
+            )
     else:
         raise UnknownError(
             "未知错误")
@@ -161,7 +154,7 @@ def pausePrint(*content,pause=0.2):
                 (pause))
         print(" ",flush=True,end="")
     print("\n",flush=True,end="")
-    
+  
 def captcha():
     """功能：生成一个CAPTCHA验证码
     不能指定位数，无参数
@@ -271,8 +264,6 @@ gr = []
 ttt = 0
 ia = None
 class find():
-    def warning(self):
-        return "1.查找文件时间和电脑性能有关（猜测）-2.使用show()的时候需要使用print"
     def getDisk(self):
         dd = []
         for disk in string.ascii_uppercase:
